@@ -1,13 +1,13 @@
 /***************************************
-  $Header: /home/amb/xbomb/RCS/hiscore.c 1.11 1998/01/16 19:50:39 amb Exp $
+  $Header: /home/amb/CVS/xbomb/hiscore.c,v 1.13 2008-01-05 19:23:07 amb Exp $
 
-  XBomb - 'Minesweeper' game - Version 2.1.
+  XBomb - 'Minesweeper' game - Version 2.2.
 
   Hi-score table management.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1994,1995,1998 Andrew M. Bishop
+  This file Copyright 1994-2007 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -16,6 +16,9 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <sys/types.h>
+#include <pwd.h>
 
 #if defined(__sun__) && !defined(__svr4__)
 int    fprintf(FILE*, const char*,...);
@@ -126,12 +129,20 @@ void AddHighScore(int ticks)
 {
  int j;
  int changed=-1;
+ struct passwd *pwd;
+ char *username;
 
  load_high_scores();
 
+ pwd=getpwuid(geteuid());
+ if(pwd)
+    username=pwd->pw_name;
+ else
+    username="?unknown?";
+
  which_hiscore=10;
  score[grid_level-GAME_LEVEL][10]=ticks;
- cuserid(name[grid_level-GAME_LEVEL][10]);
+ strcpy(name[grid_level-GAME_LEVEL][10],username);
  date[grid_level-GAME_LEVEL][10]=time(NULL);
 
  for(j=0;j<10;j++)
@@ -147,7 +158,7 @@ void AddHighScore(int ticks)
        date[grid_level-GAME_LEVEL][j]=date[grid_level-GAME_LEVEL][j-1];
       }
     score[grid_level-GAME_LEVEL][changed]=ticks;
-    cuserid(name[grid_level-GAME_LEVEL][changed]);
+    strcpy(name[grid_level-GAME_LEVEL][changed],username);
     date[grid_level-GAME_LEVEL][changed]=time(NULL);
 
     save_high_scores();
