@@ -1,13 +1,11 @@
 /***************************************
-  $Header: /home/amb/xbomb/RCS/xbomb.c 1.14 1999/04/10 18:28:49 amb Exp $
-
-  XBomb - 'Minesweeper' game - Version 2.1a.
+  XBomb - 'Minesweeper' game - Version 2.2b.
 
   Main function of program - excludes all window interface parts.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1994,1995,1998 Andrew M. Bishop
+  This file Copyright 1994-2014 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -75,9 +73,9 @@ int main(int argc,char** argv)
  long t;
 
  printf("\n"
-        "XBomb Version 2.1a\n"
+        "XBomb Version 2.2b\n"
         "\n"
-        "(c) Andrew M. Bishop 1994,95,96,97,98,99. [amb@gedanken.demon.co.uk]\n"
+        "(c) Andrew M. Bishop 1994-2013 [http://www.gedanken.org.uk/software/xbomb/]\n"
         "\n");
 
  if(argc>1)
@@ -260,7 +258,7 @@ void DrawGrid(void)
 
 
 /*++++++++++++++++++++++++++++++++++++++
-  The function that is called when a single square is selected.
+  Select a single square and clear it or explode the bomb.
 
   int x The location of the square.
 
@@ -308,6 +306,23 @@ void SelectSquare(int x,int y)
 }
 
 
+/*++++++++++++++++++++++++++++++++++++++
+  Select a single square and clear it, explode the bomb or clear the adjacent.
+
+  int x The location of the square.
+
+  int y The location of the square.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+void SelectSquareOrAdjacent(int x,int y)
+{
+ if(state[x][y]&UNSEEN)
+    SelectSquare(x,y);
+ else /* if(state[x][y]&EMPTY) */
+    SelectAdjacent(x,y);
+}
+
+
 /*++++++++++++++++++++++++++++++++++++++
   Select all of the squares adjacent
 
