@@ -1,13 +1,11 @@
 /***************************************
-  $Header: /home/amb/xbomb/RCS/xwindow.c 1.23 1999/04/10 18:28:36 amb Exp $
-
-  XBomb - 'Minesweeper' game - Version 2.1a.
+  XBomb - 'Minesweeper' game - Version 2.2b.
 
   All X Window functions.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1994,1995,1998 Andrew M. Bishop
+  This file Copyright 1994-2014 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -71,35 +69,59 @@ static void close_proc(Widget w,XtPointer va,XEvent* e,Boolean* vb);
 static void display_clock(XtPointer p,XtIntervalId i);
 static int msecs(void);
 
-/*+ A structure to hold the colour and font resource data in. +*/
-struct temp
-{
- Pixel colours[6];              /*+ The colours. +*/
- XFontStruct* fontstruct;       /*+ The font. +*/
-}
-resources;
-
-/*+ An array to hold the GCs in. +*/
-static GC gc[7];
 
 #define GC_BOMB        0        /*+ For drawing the bomb and flag foreground. +*/
 #define GC_ACTUAL_BACK 1        /*+ For drawing the bomb background. +*/
 #define GC_THINK_BACK  2        /*+ For drawing the flag background. +*/
-#define GC_NUMBERS     3        /*+ For drawing the numbers on the grid. +*/
-#define GC_UNSEEN      4        /*+ For unseen (hidden) tiles. +*/
-#define GC_CORRECT     5        /*+ For correctly guessed tiles at the end.+*/
-#define GC_BLANK       6        /*+ For blank squares. +*/
+#define GC_NUMBER1     3        /*+ For drawing the number 1 on the grid. +*/
+#define GC_NUMBER2     4        /*+ For drawing the number 2 +*/
+#define GC_NUMBER3     5        /*+ For drawing the number 3 +*/
+#define GC_NUMBER4     6        /*+ For drawing the number 4 +*/
+#define GC_NUMBER5     7        /*+ For drawing the number 5 +*/
+#define GC_NUMBER6     8        /*+ For drawing the number 6 +*/
+#define GC_NUMBER7     9        /*+ For drawing the number 7 +*/
+#define GC_NUMBER8     10       /*+ For drawing the number 8 +*/
+#define GC_NUMBER9     11       /*+ For drawing the number 9 +*/
+#define GC_NUMBER10    12       /*+ For drawing the number 10 (A) +*/
+#define GC_NUMBER11    13       /*+ For drawing the number 11 (B) +*/
+#define GC_NUMBER12    14       /*+ For drawing the number 12 (C) +*/
+#define GC_UNSEEN      15       /*+ For unseen (hidden) tiles. +*/
+#define GC_CORRECT     16       /*+ For correctly guessed tiles at the end.+*/
+#define GC_BLANK       17       /*+ For blank squares. +*/
+#define NUM_GC         18
+
+/*+ A structure to hold the colour and font resource data in. +*/
+struct temp
+{
+ XFontStruct* fontstruct;       /*+ The font. +*/
+ Pixel colours[NUM_GC-1];       /*+ The colours. +*/
+}
+resources;
+
+/*+ An array to hold the GCs in. +*/
+static GC gc[NUM_GC];
 
 /*+ The colour resources for the map. +*/
 static XtResource xresources[]=
 {
- {"bomb"    , "XBomb", XtRPixel     , sizeof(String)      , 0               , XtRString, "black" },
- {"bombreal", "XBomb", XtRPixel     , sizeof(String)      ,   sizeof(String), XtRString, "red" },
- {"bombmark", "XBomb", XtRPixel     , sizeof(String)      , 2*sizeof(String), XtRString, "orange" },
- {"number"  , "XBomb", XtRPixel     , sizeof(String)      , 3*sizeof(String), XtRString, "blue" },
- {"hidden"  , "XBomb", XtRPixel     , sizeof(String)      , 4*sizeof(String), XtRString, "grey50" },
- {"correct" , "XBomb", XtRPixel     , sizeof(String)      , 5*sizeof(String), XtRString, "green" },
- {"font"    , "XBomb", XtRFontStruct, sizeof(XFontStruct*), 6*sizeof(String), XtRString, "lucidasans-24"}
+ {"font"    , "XBomb", XtRFontStruct, sizeof(XFontStruct*), 0               , XtRString, "lucidasans-24"},
+ {"bomb"    , "XBomb", XtRPixel     , sizeof(String)      ,   sizeof(String), XtRString, "black" },
+ {"bombreal", "XBomb", XtRPixel     , sizeof(String)      , 2*sizeof(String), XtRString, "red" },
+ {"bombmark", "XBomb", XtRPixel     , sizeof(String)      , 3*sizeof(String), XtRString, "orange" },
+ {"number"  , "XBomb", XtRPixel     , sizeof(String)      , 4*sizeof(String), XtRString, "navyblue" },
+ {"number2" , "XBomb", XtRPixel     , sizeof(String)      , 5*sizeof(String), XtRString, "darkgreen" },
+ {"number3" , "XBomb", XtRPixel     , sizeof(String)      , 6*sizeof(String), XtRString, "darkred" },
+ {"number4" , "XBomb", XtRPixel     , sizeof(String)      , 7*sizeof(String), XtRString, "black" },
+ {"number5" , "XBomb", XtRPixel     , sizeof(String)      , 8*sizeof(String), XtRString, "turquoise" },
+ {"number6" , "XBomb", XtRPixel     , sizeof(String)      , 9*sizeof(String), XtRString, "orange" },
+ {"number7" , "XBomb", XtRPixel     , sizeof(String)      ,10*sizeof(String), XtRString, "violet" },
+ {"number8" , "XBomb", XtRPixel     , sizeof(String)      ,11*sizeof(String), XtRString, "lightgreen" },
+ {"number9" , "XBomb", XtRPixel     , sizeof(String)      ,12*sizeof(String), XtRString, "blue" },
+ {"number10", "XBomb", XtRPixel     , sizeof(String)      ,13*sizeof(String), XtRString, "blue" },
+ {"number11", "XBomb", XtRPixel     , sizeof(String)      ,14*sizeof(String), XtRString, "blue" },
+ {"number12", "XBomb", XtRPixel     , sizeof(String)      ,15*sizeof(String), XtRString, "blue" },
+ {"hidden"  , "XBomb", XtRPixel     , sizeof(String)      ,16*sizeof(String), XtRString, "grey50" },
+ {"correct" , "XBomb", XtRPixel     , sizeof(String)      ,17*sizeof(String), XtRString, "green" }
 };
 
 
@@ -123,7 +145,7 @@ void InitialiseX(int *argc,char **argv)
 
  toplevel=XtVaAppInitialize(&app_context,"XBomb",
                             NULL, (Cardinal)0,argc,argv,NULL,
-                            XtNtitle,"XBomb V2.1a",
+                            XtNtitle,"XBomb V2.2b",
                             XtNiconName,"XBomb",
                             NULL);
 
@@ -219,10 +241,10 @@ void InitialiseX(int *argc,char **argv)
  XtVaGetSubresources(play_area,(XtPointer)&resources,"grid","XBomb",xresources,XtNumber(xresources),NULL);
 
  values.font=resources.fontstruct->fid;
- for(i=0;i<6;i++)
+ for(i=0;i<NUM_GC-1;i++)
    {
     values.foreground=resources.colours[i];
-    if(i==4)
+    if(i==GC_UNSEEN)
       {
        GC tempgc;
        XGCValues gcxval;
@@ -260,7 +282,7 @@ void InitialiseX(int *argc,char **argv)
  /* The highscore table. */
 
  highscore=XtVaCreatePopupShell("hiscores",topLevelShellWidgetClass,toplevel,
-                                XtNtitle,"XBomb V2.1a High Scores",XtNiconName,"XBomb Hi-scores",
+                                XtNtitle,"XBomb V2.2b High Scores",XtNiconName,"XBomb Hi-scores",
                                 XtNmappedWhenManaged,False,
                                 NULL);
 
@@ -316,7 +338,7 @@ void InitialiseX(int *argc,char **argv)
 
  /* Centre the text */
 
- fontstruct=XQueryFont(display,XGContextFromGC(gc[GC_NUMBERS]));
+ fontstruct=XQueryFont(display,XGContextFromGC(gc[GC_NUMBER1]));
 
  xoffset=XTextWidth(fontstruct,"0",1)/2;
  yoffset=fontstruct->ascent/2;
@@ -343,7 +365,7 @@ void FinishUpX(void)
 
  /* Free the graphics contexts. */
 
- for(i=0;i<7;i++)
+ for(i=0;i<NUM_GC;i++)
     XFreeGC(display,gc[i]);
 
  /* Free the pixmaps. */
@@ -465,7 +487,8 @@ void DrawSquare(int x,int y,unsigned char value)
    {
     int text_xpos=xpos+pixw/2-xoffset;
     int text_ypos=ypos+pixh/2+yoffset;
-    XDrawString(display,play_window,gc[GC_NUMBERS],text_xpos,text_ypos,grid_numbers[(value&~CORRECT)],1);
+    int gc_number=(value&~CORRECT)+GC_NUMBER1-1;  /* Calculate GC_NUMBERx offset. */
+    XDrawString(display,play_window,gc[gc_number],text_xpos,text_ypos,grid_numbers[(value&~CORRECT)],1);
    }
 
  /* Draw the correct squares at the end. */
@@ -752,7 +775,7 @@ static void mouse_press_proc(Widget w,XtPointer va,XEvent* e,Boolean* vb)
 
  switch(e->xbutton.button)
    {
-   case 1: SelectSquare(x,y); break;
+   case 1: SelectSquareOrAdjacent(x,y); break;
    case 2: SelectAdjacent(x,y); break;
    case 3: MarkBomb(x,y); break;
    }
